"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const devkit_1 = require("@nx/devkit");
// eslint-disable-next-line n/no-sync
const node_child_process_1 = require("node:child_process");
const cli_1 = require("../internal/cli");
const context_1 = require("../internal/context");
const utils_1 = require("./utils");
function runAutorunExecutor(terminalAndExecutorOptions, context) {
    const normalizedContext = (0, context_1.normalizeContext)(context);
    const cliArgumentObject = (0, utils_1.parseAutorunExecutorOptions)(terminalAndExecutorOptions, normalizedContext);
    const { dryRun, verbose, command } = terminalAndExecutorOptions;
    const commandString = (0, cli_1.createCliCommand)({ command, args: cliArgumentObject });
    const commandStringOptions = context.cwd ? { cwd: context.cwd } : {};
    if (verbose) {
        devkit_1.logger.info(`Run CLI executor ${command ?? ''}`);
        devkit_1.logger.info(`Command: ${commandString}`);
    }
    if (dryRun) {
        devkit_1.logger.warn(`DryRun execution of: ${commandString}`);
    }
    else {
        try {
            // @TODO use executeProcess instead of execSync -> non blocking, logs #761
            // eslint-disable-next-line n/no-sync
            (0, node_child_process_1.execSync)(commandString, commandStringOptions);
        }
        catch (error) {
            devkit_1.logger.error(error);
            return Promise.resolve({
                success: false,
                command: commandString,
                error: error,
            });
        }
    }
    return Promise.resolve({
        success: true,
        command: commandString,
    });
}
exports.default = runAutorunExecutor;
//# sourceMappingURL=executor.js.map