"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.objectToCliArgs = exports.createCliCommand = void 0;
function createCliCommand(options) {
    const { bin = '@code-pushup/cli', command, args } = options ?? {};
    return `npx ${bin} ${objectToCliArgs({ _: command ?? [], ...args }).join(' ')}`;
}
exports.createCliCommand = createCliCommand;
// @TODO import from @code-pushup/utils => get rid of poppins for cjs support
// eslint-disable-next-line sonarjs/cognitive-complexity
function objectToCliArgs(params) {
    if (!params) {
        return [];
    }
    // eslint-disable-next-line @typescript-eslint/no-unsafe-return
    return Object.entries(params).flatMap(([key, value]) => {
        // process/file/script
        if (key === '_') {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-return
            return (Array.isArray(value) ? value : [`${value}`]).filter(v => v != null);
        }
        const prefix = key.length === 1 ? '-' : '--';
        // "-*" arguments (shorthands)
        if (Array.isArray(value)) {
            return value.map(v => `${prefix}${key}="${v}"`);
        }
        if (typeof value === 'object') {
            return Object.entries(value).flatMap(
            // transform nested objects to the dot notation `key.subkey`
            ([k, v]) => objectToCliArgs({ [`${key}.${k}`]: v }));
        }
        if (typeof value === 'string') {
            return [`${prefix}${key}="${value}"`];
        }
        if (typeof value === 'number') {
            return [`${prefix}${key}=${value}`];
        }
        if (typeof value === 'boolean') {
            return [`${prefix}${value ? '' : 'no-'}${key}`];
        }
        if (value === undefined) {
            return [];
        }
        throw new Error(`Unsupported type ${typeof value} for key ${key}`);
    });
}
exports.objectToCliArgs = objectToCliArgs;
//# sourceMappingURL=cli.js.map