"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCodePushupConfig = exports.DEFAULT_IMPORTS = void 0;
const devkit_1 = require("@nx/devkit");
const node_path_1 = require("node:path");
const utils_1 = require("./utils");
exports.DEFAULT_IMPORTS = [
    "import type { CoreConfig } from '@code-pushup/models';",
];
function generateCodePushupConfig(tree, root, options) {
    const supportedFormats = ['ts', 'mjs', 'js'];
    const firstExistingFormat = supportedFormats.find(ext => tree.exists((0, node_path_1.join)(root, `code-pushup.config.${ext}`)));
    if (firstExistingFormat) {
        devkit_1.logger.warn(`NOTE: No config file created as code-pushup.config.${firstExistingFormat} file already exists.`);
    }
    else {
        const { fileImports: rawImports, persist, upload, plugins: rawPlugins = [], // plugins are required
        categories: rawCategories, } = options ?? {};
        const plugins = rawPlugins.map(utils_1.normalizeExecutableCode);
        const categories = rawCategories?.map(utils_1.normalizeExecutableCode);
        const configFileImports = [
            ...(rawImports ? (0, utils_1.normalizeItemOrArray)(rawImports) : exports.DEFAULT_IMPORTS),
            ...plugins.flatMap(({ fileImports }) => fileImports),
            ...(categories ?? []).flatMap(({ fileImports }) => fileImports),
        ];
        (0, devkit_1.generateFiles)(tree, (0, node_path_1.join)(__dirname, 'files'), root, {
            ...options,
            fileImports: (0, utils_1.formatArrayToLinesOfJsString)(configFileImports),
            persist: (0, utils_1.formatObjectToFormattedJsString)(persist),
            upload: (0, utils_1.formatObjectToFormattedJsString)(upload),
            plugins: (0, utils_1.formatArrayToJSArray)(plugins.flatMap(({ codeStrings }) => codeStrings)),
            categories: categories &&
                (0, utils_1.formatArrayToJSArray)(categories.flatMap(({ codeStrings }) => codeStrings)),
        });
    }
}
exports.generateCodePushupConfig = generateCodePushupConfig;
//# sourceMappingURL=code-pushup-config.js.map