"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatArrayToJSArray = exports.formatArrayToLinesOfJsString = exports.formatObjectToFormattedJsString = exports.normalizeItemOrArray = exports.normalizeExecutableCode = void 0;
function normalizeExecutableCode(executableCode) {
    const { fileImports: rawFileImports, codeStrings: rawCodeStrings } = executableCode;
    return {
        fileImports: normalizeItemOrArray(rawFileImports),
        codeStrings: normalizeItemOrArray(rawCodeStrings),
    };
}
exports.normalizeExecutableCode = normalizeExecutableCode;
function normalizeItemOrArray(itemOrArray) {
    if (itemOrArray == null) {
        return undefined;
    }
    if (Array.isArray(itemOrArray)) {
        return itemOrArray;
    }
    return [itemOrArray];
}
exports.normalizeItemOrArray = normalizeItemOrArray;
// Return a formatted JSON in TS object with the same keys as the input object but remove the " for the properties
function formatObjectToFormattedJsString(jsonObj) {
    if (!jsonObj) {
        return;
    }
    // Convert JSON object to a string with indentation
    const jsonString = JSON.stringify(jsonObj, null, 2);
    // Remove double quotes around property names
    return jsonString.replace(/"(\w+)":/g, '$1:');
}
exports.formatObjectToFormattedJsString = formatObjectToFormattedJsString;
function formatArrayToLinesOfJsString(lines, separator = '\n') {
    if (lines == null || lines.length === 0) {
        return;
    }
    return lines.join(separator).replace(/'/g, '"');
}
exports.formatArrayToLinesOfJsString = formatArrayToLinesOfJsString;
function formatArrayToJSArray(lines) {
    if (!Array.isArray(lines)) {
        return;
    }
    return `[${formatArrayToLinesOfJsString(lines, ',\n') ?? ''}]`.replace(/"/g, '');
}
exports.formatArrayToJSArray = formatArrayToJSArray;
//# sourceMappingURL=utils.js.map